@@ -36,15 +36,11 @@ get_embeddings <- function(text,
           "Accept" = 'application/json',
           "Authorization" = paste("Bearer", Sys.getenv('MISTRAL_API_KEY'))
         ) |>
-        httr2::req_body_json(list(model = model, input = chunk))
+        httr2::req_body_json(list(model = model, input = chunk)) |>
+        httr2::req_retry(max_tries = 5,
+                         is_transient = \(resp) httr2::resp_status(resp) %in% c(429, 500:504))
     }
 
-    # split the embeddings into chunks, because the Mistral
-    # embeddings endpoint will only take so many tokens at a time
-
-    # requests per minute
-    rpm <- 6 * 60
-
     # max tokens per request
     tpr <- 8192
     # max characters per chunk is approximately max tokens times 2 (*very* conservative)
@@ -62,60 +58,27 @@ get_embeddings <- function(text,
       stop("No API key detected. Set OPENAI_API_KEY in .Renviron or pass as argument.")
     }
 
-    # is_project_scoped <- function(key) {
-    #   grepl("^sk-proj-", key)
-    # }
-    #
-    # get_project_id <- function(api_key) {
-    #   if (!is_project_scoped(api_key))
-    #     return(NULL)
-    #   project_id <- Sys.getenv("OPENAI_PROJECT_ID")
-    #   if (project_id == "") {
-    #     stop(
-    #       "You are using a project-scoped key (sk-proj-...), but OPENAI_PROJECT_ID is not set.\n\nAdd this line to your .Renviron:\nOPENAI_PROJECT_ID=project_xxxxxx\n"
-    #     )
-    #   }
-    #   return(project_id)
-    # }
-
     # format an API request to embeddings endpoint
     format_request <- function(chunk, base_url = "https://api.openai.com/v1/embeddings") {
-      # project_id <- get_project_id(openai_api_key)
-
-      # ⚠️ Use a named character vector to avoid collapsing
       headers <- c(
         "Authorization" = paste("Bearer", openai_api_key),
         "Content-Type" = "application/json"
       )
-      # if (!is.null(project_id)) {
-      #   headers["OpenAI-Project"] <- project_id
-      # }
 
       httr2::request(base_url) |>
-        # headers
         httr2::req_headers(!!!headers) |>
-        # body
         httr2::req_body_json(list(
           model = model,
           input = chunk,
           dimensions = dimensions
-        ))
+        )) |>
+        httr2::req_retry(max_tries = 5,
+                         is_transient = \(resp) httr2::resp_status(resp) %in% c(429, 500:504))
     }
 
-    # get the user's rate limits
-    req <- format_request("test")
-    resp <- httr2::req_perform(req)
-    # requests per minute
-    rpm <- as.numeric(httr2::resp_header(resp, 'x-ratelimit-limit-requests'))
-    # tokens per minute
-    tpm <- as.numeric(httr2::resp_header(resp, 'x-ratelimit-limit-tokens'))
-
     # max tokens per request is currently 8192
     tpr <- 8192
 
-    # "effective" rpm may be smaller than rpm if we're splitting into chunks of 8192
-    rpm <- min(c(rpm, floor(tpm / tpr)))
-
     # split the embeddings into chunks, because the OpenAI
     # embeddings endpoint will only take so many tokens at a time
 
@@ -141,8 +104,7 @@ get_embeddings <- function(text,
     # submit prompts in parallel (20 concurrent requests per host seems to be the optimum)
     resps <- httr2::req_perform_parallel(reqs, max_active = 20, on_error = 'continue')
   } else {
-    resps <- lapply(reqs, httr2::req_throttle, rate = rpm / 60) |>
-      httr2::req_perform_sequential()
+    resps <- httr2::req_perform_sequential(reqs)
   }
 
   status_codes <- vapply(resps, function(x)
@@ -156,7 +118,7 @@ get_embeddings <- function(text,
   } else if (any(status_codes == 404)) {
     stop('404 Not Found. Check the spelling of the `model` or `embedding_model` inputs.')
   } else if (any(status_codes == 429)) {
-    stop('429 Too Many Requests. The API is not allowing you to retrieve this many embeddings. Please ensure that you have enough credits to use the API. You can also set `parallel = FALSE` for improved rate limit handling.')
+    stop('429 Too Many Requests. The API is not allowing you to retrieve this many embeddings. Please ensure that you have enough credits to use the API.')
   } else if (any(status_codes %in% 500:504)) {
       stop('500-504 Server Side Error. Something went wrong with the OpenAI server. Not your fault. Try again later.')
   }
